@@ -1,6 +1,7 @@
 use clap::{App, AppSettings, Arg, SubCommand};
 
-use firework_lang::build_system::FireworkProject;
+use firework_lang::firework_project::FireworkProject;
+use firework_lang::repl::Repl;
 
 fn main() {
     let clap_app = App::new("Firework")
@@ -9,7 +10,9 @@ fn main() {
         .author(env!("CARGO_PKG_AUTHORS"))
         .about(env!("CARGO_PKG_DESCRIPTION"))
         .subcommand(SubCommand::with_name("new").arg(Arg::with_name("project").takes_value(true)))
-        .subcommand(SubCommand::with_name("run").help("Runs firework project"));
+        .subcommand(SubCommand::with_name("build").help("Builds a firework project"))
+        .subcommand(SubCommand::with_name("run").help("Runs a firework project"))
+        .subcommand(SubCommand::with_name("repl").help("Runs the firework repl"));
 
     let matches = clap_app.get_matches();
     let project = FireworkProject::new();
@@ -21,6 +24,8 @@ fn main() {
                 project.new_project(project_name)
             }
         }
+        ("repl", _) => Repl::new().repl_loop(),
+        ("build", _) => project.build().unwrap_or_else(|err| panic!("{}", err)),
         _ => {}
     }
 }
